---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2012-08-07;134
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20120811&codiceRedaz=012G0152&dataVigenza=20251104
dataGU: 20120811
codiceRedaz: 012G0152
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 22 giugno 2012, n. 83, recante misure urgenti per la crescita del Paese. (12G0152)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 22 giugno 2012, n. 83, recante misure urgenti per la crescita del Paese, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

